@@ -25,14 +25,14 @@ class ValidateTemplateContentRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'oos', '2019-06-01', 'ValidateTemplateContent','oos')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Content(self):
+	def get_Content(self): # String
 		return self.get_query_params().get('Content')
 
-	def set_Content(self,Content):
-		self.add_query_param('Content',Content)
\ No newline at end of file
+	def set_Content(self, Content):  # String
+		self.add_query_param('Content', Content)
